==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/FrontendIPConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.FrontendIPConfigurationArgs.builder
import com.pulumi.azurenative.network.kotlin.enums.IPAllocationMethod
import com.pulumi.azurenative.network.kotlin.enums.IPVersion
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Frontend IP address of the load balancer.
 * @property gatewayLoadBalancer The reference to gateway load balancer frontend IP.
 * @property id Resource ID.
 * @property name The name of the resource that is unique within the set of frontend IP configurations used by the load balancer. This name can be used to access the resource.
 * @property privateIPAddress The private IP address of the IP configuration.
 * @property privateIPAddressVersion Whether the specific ipconfiguration is IPv4 or IPv6. Default is taken as IPv4.
 * @property privateIPAllocationMethod The Private IP allocation method.
 * @property publicIPAddress The reference to the Public IP resource.
 * @property publicIPPrefix The reference to the Public IP Prefix resource.
 * @property subnet The reference to the subnet resource.
 * @property zones A list of availability zones denoting the IP allocated for the resource needs to come from.
 */
public data class FrontendIPConfigurationArgs(
    public val gatewayLoadBalancer: Output<SubResourceArgs>? = null,
    public val id: Output<String>? = null,
    public val name: Output<String>? = null,
    public val privateIPAddress: Output<String>? = null,
    public val privateIPAddressVersion: Output<Either<String, IPVersion>>? = null,
    public val privateIPAllocationMethod: Output<Either<String, IPAllocationMethod>>? = null,
    public val publicIPAddress: Output<PublicIPAddressArgs>? = null,
    public val publicIPPrefix: Output<SubResourceArgs>? = null,
    public val subnet: Output<SubnetArgs>? = null,
    public val zones: Output<List<String>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.network.inputs.FrontendIPConfigurationArgs> {
    override fun toJava(): com.pulumi.azurenative.network.inputs.FrontendIPConfigurationArgs =
        com.pulumi.azurenative.network.inputs.FrontendIPConfigurationArgs.builder()
            .gatewayLoadBalancer(
                gatewayLoadBalancer?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .id(id?.applyValue({ args0 -> args0 }))
            .name(name?.applyValue({ args0 -> args0 }))
            .privateIPAddress(privateIPAddress?.applyValue({ args0 -> args0 }))
            .privateIPAddressVersion(
                privateIPAddressVersion?.applyValue({ args0 ->
                    args0.transform({ args0 ->
                        args0
                    }, { args0 -> args0.let({ args0 -> args0.toJava() }) })
                }),
            )
            .privateIPAllocationMethod(
                privateIPAllocationMethod?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 -> args0.let({ args0 -> args0.toJava() }) })
                }),
            )
            .publicIPAddress(publicIPAddress?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .publicIPPrefix(publicIPPrefix?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .subnet(subnet?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .zones(zones?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [FrontendIPConfigurationArgs].
 */
@PulumiTagMarker
public class FrontendIPConfigurationArgsBuilder internal constructor() {
    private var gatewayLoadBalancer: Output<SubResourceArgs>? = null

    private var id: Output<String>? = null

    private var name: Output<String>? = null

    private var privateIPAddress: Output<String>? = null

    private var privateIPAddressVersion: Output<Either<String, IPVersion>>? = null

    private var privateIPAllocationMethod: Output<Either<String, IPAllocationMethod>>? = null

    private var publicIPAddress: Output<PublicIPAddressArgs>? = null

    private var publicIPPrefix: Output<SubResourceArgs>? = null

    private var subnet: Output<SubnetArgs>? = null

    private var zones: Output<List<String>>? = null

    /**
     * @param value The reference to gateway load balancer frontend IP.
     */
    @JvmName("ovvprccwgoojuluu")
    public suspend fun gatewayLoadBalancer(`value`: Output<SubResourceArgs>) {
        this.gatewayLoadBalancer = value
    }

    /**
     * @param value Resource ID.
     */
    @JvmName("tcpojlqoeijpypho")
    public suspend fun id(`value`: Output<String>) {
        this.id = value
    }

    /**
     * @param value The name of the resource that is unique within the set of frontend IP configurations used by the load balancer. This name can be used to access the resource.
     */
    @JvmName("hktuigwjourlfpoh")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value The private IP address of the IP configuration.
     */
    @JvmName("pmsbknbavcwhjiri")
    public suspend fun privateIPAddress(`value`: Output<String>) {
        this.privateIPAddress = value
    }

    /**
     * @param value Whether the specific ipconfiguration is IPv4 or IPv6. Default is taken as IPv4.
     */
    @JvmName("hlpiudbiqtccrcqw")
    public suspend fun privateIPAddressVersion(`value`: Output<Either<String, IPVersion>>) {
        this.privateIPAddressVersion = value
    }

    /**
     * @param value The Private IP allocation method.
     */
    @JvmName("tbcvkmewecqgjfnq")
    public suspend
    fun privateIPAllocationMethod(`value`: Output<Either<String, IPAllocationMethod>>) {
        this.privateIPAllocationMethod = value
    }

    /**
     * @param value The reference to the Public IP resource.
     */
    @JvmName("thqvtxfeksqlwgpy")
    public suspend fun publicIPAddress(`value`: Output<PublicIPAddressArgs>) {
        this.publicIPAddress = value
    }

    /**
     * @param value The reference to the Public IP Prefix resource.
     */
    @JvmName("nvtyhcdivmvgysil")
    public suspend fun publicIPPrefix(`value`: Output<SubResourceArgs>) {
        this.publicIPPrefix = value
    }

    /**
     * @param value The reference to the subnet resource.
     */
    @JvmName("yhgxpvtvhrhngndx")
    public suspend fun subnet(`value`: Output<SubnetArgs>) {
        this.subnet = value
    }

    /**
     * @param value A list of availability zones denoting the IP allocated for the resource needs to come from.
     */
    @JvmName("fqxhprpdkdvphxyf")
    public suspend fun zones(`value`: Output<List<String>>) {
        this.zones = value
    }

    @JvmName("nmwynootqmagjvkm")
    public suspend fun zones(vararg values: Output<String>) {
        this.zones = Output.all(values.asList())
    }

    /**
     * @param values A list of availability zones denoting the IP allocated for the resource needs to come from.
     */
    @JvmName("vssheeyhnhlyjjwb")
    public suspend fun zones(values: List<Output<String>>) {
        this.zones = Output.all(values)
    }

    /**
     * @param value The reference to gateway load balancer frontend IP.
     */
    @JvmName("jslamgnfrrhyfbeh")
    public suspend fun gatewayLoadBalancer(`value`: SubResourceArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.gatewayLoadBalancer = mapped
    }

    /**
     * @param argument The reference to gateway load balancer frontend IP.
     */
    @JvmName("hphcqmfjgmunojdl")
    public suspend fun gatewayLoadBalancer(argument: suspend SubResourceArgsBuilder.() -> Unit) {
        val toBeMapped = SubResourceArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.gatewayLoadBalancer = mapped
    }

    /**
     * @param value Resource ID.
     */
    @JvmName("qcjgibraqjfqiiqy")
    public suspend fun id(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.id = mapped
    }

    /**
     * @param value The name of the resource that is unique within the set of frontend IP configurations used by the load balancer. This name can be used to access the resource.
     */
    @JvmName("xnqdvjcjwtbwhtrx")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The private IP address of the IP configuration.
     */
    @JvmName("dsfigqwqeadfycck")
    public suspend fun privateIPAddress(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.privateIPAddress = mapped
    }

    /**
     * @param value Whether the specific ipconfiguration is IPv4 or IPv6. Default is taken as IPv4.
     */
    @JvmName("qnmikmokmgkysgbl")
    public suspend fun privateIPAddressVersion(`value`: Either<String, IPVersion>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.privateIPAddressVersion = mapped
    }

    /**
     * @param value Whether the specific ipconfiguration is IPv4 or IPv6. Default is taken as IPv4.
     */
    @JvmName("kwrmtdujpyncpqnh")
    public fun privateIPAddressVersion(`value`: String) {
        val toBeMapped = Either.ofLeft<String, IPVersion>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.privateIPAddressVersion = mapped
    }

    /**
     * @param value Whether the specific ipconfiguration is IPv4 or IPv6. Default is taken as IPv4.
     */
    @JvmName("smhdbqxpkccjtlke")
    public fun privateIPAddressVersion(`value`: IPVersion) {
        val toBeMapped = Either.ofRight<String, IPVersion>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.privateIPAddressVersion = mapped
    }

    /**
     * @param value The Private IP allocation method.
     */
    @JvmName("mmwonvhxjgxkbywv")
    public suspend fun privateIPAllocationMethod(`value`: Either<String, IPAllocationMethod>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.privateIPAllocationMethod = mapped
    }

    /**
     * @param value The Private IP allocation method.
     */
    @JvmName("ybqldcelaiecvvhu")
    public fun privateIPAllocationMethod(`value`: String) {
        val toBeMapped = Either.ofLeft<String, IPAllocationMethod>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.privateIPAllocationMethod = mapped
    }

    /**
     * @param value The Private IP allocation method.
     */
    @JvmName("fsflvoheqiahhnht")
    public fun privateIPAllocationMethod(`value`: IPAllocationMethod) {
        val toBeMapped = Either.ofRight<String, IPAllocationMethod>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.privateIPAllocationMethod = mapped
    }

    /**
     * @param value The reference to the Public IP resource.
     */
    @JvmName("wqwcctdijkvhbbio")
    public suspend fun publicIPAddress(`value`: PublicIPAddressArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.publicIPAddress = mapped
    }

    /**
     * @param argument The reference to the Public IP resource.
     */
    @JvmName("gqrechhawmlhmtox")
    public suspend fun publicIPAddress(argument: suspend PublicIPAddressArgsBuilder.() -> Unit) {
        val toBeMapped = PublicIPAddressArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.publicIPAddress = mapped
    }

    /**
     * @param value The reference to the Public IP Prefix resource.
     */
    @JvmName("lrblxjcxtqncfoos")
    public suspend fun publicIPPrefix(`value`: SubResourceArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.publicIPPrefix = mapped
    }

    /**
     * @param argument The reference to the Public IP Prefix resource.
     */
    @JvmName("wjgeoswerqnlstty")
    public suspend fun publicIPPrefix(argument: suspend SubResourceArgsBuilder.() -> Unit) {
        val toBeMapped = SubResourceArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.publicIPPrefix = mapped
    }

    /**
     * @param value The reference to the subnet resource.
     */
    @JvmName("sdvrtgdupfdexmib")
    public suspend fun subnet(`value`: SubnetArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.subnet = mapped
    }

    /**
     * @param argument The reference to the subnet resource.
     */
    @JvmName("yvgbfjkbyvkkblvu")
    public suspend fun subnet(argument: suspend SubnetArgsBuilder.() -> Unit) {
        val toBeMapped = SubnetArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.subnet = mapped
    }

    /**
     * @param value A list of availability zones denoting the IP allocated for the resource needs to come from.
     */
    @JvmName("nxorwlmychatowvg")
    public suspend fun zones(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.zones = mapped
    }

    /**
     * @param values A list of availability zones denoting the IP allocated for the resource needs to come from.
     */
    @JvmName("yafrnfgiuuehoqup")
    public suspend fun zones(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.zones = mapped
    }

    internal fun build(): FrontendIPConfigurationArgs = FrontendIPConfigurationArgs(
        gatewayLoadBalancer = gatewayLoadBalancer,
        id = id,
        name = name,
        privateIPAddress = privateIPAddress,
        privateIPAddressVersion = privateIPAddressVersion,
        privateIPAllocationMethod = privateIPAllocationMethod,
        publicIPAddress = publicIPAddress,
        publicIPPrefix = publicIPPrefix,
        subnet = subnet,
        zones = zones,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/FrontendIPConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.FrontendIPConfigurationArgs.builder
import com.pulumi.azurenative.network.kotlin.enums.IPAllocationMethod
import com.pulumi.azurenative.network.kotlin.enums.IPVersion
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Frontend IP address of the load balancer.
 * @property gatewayLoadBalancer The reference to gateway load balancer frontend IP.
 * @property id Resource ID.
 * @property name The name of the resource that is unique within the set of frontend IP configurations used by the load balancer. This name can be used to access the resource.
 * @property privateIPAddress The private IP address of the IP configuration.
 * @property privateIPAddressVersion Whether the specific ipconfiguration is IPv4 or IPv6. Default is taken as IPv4.
 * @property privateIPAllocationMethod The Private IP allocation method.
 * @property publicIPAddress The reference to the Public IP resource.
 * @property publicIPPrefix The reference to the Public IP Prefix resource.
 * @property subnet The reference to the subnet resource.
 * @property zones A list of availability zones denoting the IP allocated for the resource needs to come from.
 */
public data class FrontendIPConfigurationArgs(
    public val gatewayLoadBalancer: Output<SubResourceArgs>? = null,
    public val id: Output<String>? = null,
    public val name: Output<String>? = null,
    public val privateIPAddress: Output<String>? = null,
    public val privateIPAddressVersion: Output<Either<String, IPVersion>>? = null,
    public val privateIPAllocationMethod: Output<Either<String, IPAllocationMethod>>? = null,
    public val publicIPAddress: Output<PublicIPAddressArgs>? = null,
    public val publicIPPrefix: Output<SubResourceArgs>? = null,
    public val subnet: Output<SubnetArgs>? = null,
    public val zones: Output<List<String>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.network.inputs.FrontendIPConfigurationArgs> {
    override fun toJava(): com.pulumi.azurenative.network.inputs.FrontendIPConfigurationArgs =
        com.pulumi.azurenative.network.inputs.FrontendIPConfigurationArgs.builder()
            .gatewayLoadBalancer(
                gatewayLoadBalancer?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .id(id?.applyValue({ args0 -> args0 }))
            .name(name?.applyValue({ args0 -> args0 }))
            .privateIPAddress(privateIPAddress?.applyValue({ args0 -> args0 }))
            .privateIPAddressVersion(
                privateIPAddressVersion?.applyValue({ args0 ->
                    args0.transform({ args0 ->
                        args0
                    }, { args0 -> args0.let({ args0 -> args0.toJava() }) })
                }),
            )
            .privateIPAllocationMethod(
                privateIPAllocationMethod?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 -> args0.let({ args0 -> args0.toJava() }) })
                }),
            )
            .publicIPAddress(publicIPAddress?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .publicIPPrefix(publicIPPrefix?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .subnet(subnet?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .zones(zones?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [FrontendIPConfigurationArgs].
 */
@PulumiTagMarker
public class FrontendIPConfigurationArgsBuilder internal constructor() {
    private var gatewayLoadBalancer: Output<SubResourceArgs>? = null

    private var id: Output<String>? = null

    private var name: Output<String>? = null

    private var privateIPAddress: Output<String>? = null

    private var privateIPAddressVersion: Output<Either<String, IPVersion>>? = null

    private var privateIPAllocationMethod: Output<Either<String, IPAllocationMethod>>? = null

    private var publicIPAddress: Output<PublicIPAddressArgs>? = null

    private var publicIPPrefix: Output<SubResourceArgs>? = null

    private var subnet: Output<SubnetArgs>? = null

    private var zones: Output<List<String>>? = null

    /**
     * @param value The reference to gateway load balancer frontend IP.
     */
    @JvmName("pwneblgnexyhxscy")
    public suspend fun gatewayLoadBalancer(`value`: Output<SubResourceArgs>) {
        this.gatewayLoadBalancer = value
    }

    /**
     * @param value Resource ID.
     */
    @JvmName("xitbkaxatahhufde")
    public suspend fun id(`value`: Output<String>) {
        this.id = value
    }

    /**
     * @param value The name of the resource that is unique within the set of frontend IP configurations used by the load balancer. This name can be used to access the resource.
     */
    @JvmName("yafcbamfcdebdult")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value The private IP address of the IP configuration.
     */
    @JvmName("rsfccrhorfrgnnaw")
    public suspend fun privateIPAddress(`value`: Output<String>) {
        this.privateIPAddress = value
    }

    /**
     * @param value Whether the specific ipconfiguration is IPv4 or IPv6. Default is taken as IPv4.
     */
    @JvmName("wodrtmdldsdcfaem")
    public suspend fun privateIPAddressVersion(`value`: Output<Either<String, IPVersion>>) {
        this.privateIPAddressVersion = value
    }

    /**
     * @param value The Private IP allocation method.
     */
    @JvmName("yljidpywwbgmtmgv")
    public suspend
    fun privateIPAllocationMethod(`value`: Output<Either<String, IPAllocationMethod>>) {
        this.privateIPAllocationMethod = value
    }

    /**
     * @param value The reference to the Public IP resource.
     */
    @JvmName("lahecocbseoriond")
    public suspend fun publicIPAddress(`value`: Output<PublicIPAddressArgs>) {
        this.publicIPAddress = value
    }

    /**
     * @param value The reference to the Public IP Prefix resource.
     */
    @JvmName("gyykxqyxcxvfykgd")
    public suspend fun publicIPPrefix(`value`: Output<SubResourceArgs>) {
        this.publicIPPrefix = value
    }

    /**
     * @param value The reference to the subnet resource.
     */
    @JvmName("qocjuxiqynhejoaf")
    public suspend fun subnet(`value`: Output<SubnetArgs>) {
        this.subnet = value
    }

    /**
     * @param value A list of availability zones denoting the IP allocated for the resource needs to come from.
     */
    @JvmName("sktiajjymuoiatlf")
    public suspend fun zones(`value`: Output<List<String>>) {
        this.zones = value
    }

    @JvmName("bcdxgmocrxoohlqg")
    public suspend fun zones(vararg values: Output<String>) {
        this.zones = Output.all(values.asList())
    }

    /**
     * @param values A list of availability zones denoting the IP allocated for the resource needs to come from.
     */
    @JvmName("xcxijxsbvbhoogbh")
    public suspend fun zones(values: List<Output<String>>) {
        this.zones = Output.all(values)
    }

    /**
     * @param value The reference to gateway load balancer frontend IP.
     */
    @JvmName("yxuccdwfhulylcvg")
    public suspend fun gatewayLoadBalancer(`value`: SubResourceArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.gatewayLoadBalancer = mapped
    }

    /**
     * @param argument The reference to gateway load balancer frontend IP.
     */
    @JvmName("ugxkynjfychwfjuk")
    public suspend fun gatewayLoadBalancer(argument: suspend SubResourceArgsBuilder.() -> Unit) {
        val toBeMapped = SubResourceArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.gatewayLoadBalancer = mapped
    }

    /**
     * @param value Resource ID.
     */
    @JvmName("sxifienmuosfpjiw")
    public suspend fun id(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.id = mapped
    }

    /**
     * @param value The name of the resource that is unique within the set of frontend IP configurations used by the load balancer. This name can be used to access the resource.
     */
    @JvmName("vfkwurcqshsyidac")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The private IP address of the IP configuration.
     */
    @JvmName("frjpkrgmjxwamyqe")
    public suspend fun privateIPAddress(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.privateIPAddress = mapped
    }

    /**
     * @param value Whether the specific ipconfiguration is IPv4 or IPv6. Default is taken as IPv4.
     */
    @JvmName("ahggarxgnlrcvqiu")
    public suspend fun privateIPAddressVersion(`value`: Either<String, IPVersion>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.privateIPAddressVersion = mapped
    }

    /**
     * @param value Whether the specific ipconfiguration is IPv4 or IPv6. Default is taken as IPv4.
     */
    @JvmName("pjtktxslinknohhv")
    public fun privateIPAddressVersion(`value`: String) {
        val toBeMapped = Either.ofLeft<String, IPVersion>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.privateIPAddressVersion = mapped
    }

    /**
     * @param value Whether the specific ipconfiguration is IPv4 or IPv6. Default is taken as IPv4.
     */
    @JvmName("wfjgelcdhtcswehe")
    public fun privateIPAddressVersion(`value`: IPVersion) {
        val toBeMapped = Either.ofRight<String, IPVersion>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.privateIPAddressVersion = mapped
    }

    /**
     * @param value The Private IP allocation method.
     */
    @JvmName("gdyufrawhudiyybj")
    public suspend fun privateIPAllocationMethod(`value`: Either<String, IPAllocationMethod>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.privateIPAllocationMethod = mapped
    }

    /**
     * @param value The Private IP allocation method.
     */
    @JvmName("rowxwjtfbtssgymf")
    public fun privateIPAllocationMethod(`value`: String) {
        val toBeMapped = Either.ofLeft<String, IPAllocationMethod>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.privateIPAllocationMethod = mapped
    }

    /**
     * @param value The Private IP allocation method.
     */
    @JvmName("vxjtgxpdjdryxppv")
    public fun privateIPAllocationMethod(`value`: IPAllocationMethod) {
        val toBeMapped = Either.ofRight<String, IPAllocationMethod>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.privateIPAllocationMethod = mapped
    }

    /**
     * @param value The reference to the Public IP resource.
     */
    @JvmName("sxkdhhjqjcqkpfuw")
    public suspend fun publicIPAddress(`value`: PublicIPAddressArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.publicIPAddress = mapped
    }

    /**
     * @param argument The reference to the Public IP resource.
     */
    @JvmName("hyoybimmxomfmjck")
    public suspend fun publicIPAddress(argument: suspend PublicIPAddressArgsBuilder.() -> Unit) {
        val toBeMapped = PublicIPAddressArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.publicIPAddress = mapped
    }

    /**
     * @param value The reference to the Public IP Prefix resource.
     */
    @JvmName("ryjfyhtlhfubnyeo")
    public suspend fun publicIPPrefix(`value`: SubResourceArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.publicIPPrefix = mapped
    }

    /**
     * @param argument The reference to the Public IP Prefix resource.
     */
    @JvmName("jeocqyknncmxvujh")
    public suspend fun publicIPPrefix(argument: suspend SubResourceArgsBuilder.() -> Unit) {
        val toBeMapped = SubResourceArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.publicIPPrefix = mapped
    }

    /**
     * @param value The reference to the subnet resource.
     */
    @JvmName("blchnkcmakbiutco")
    public suspend fun subnet(`value`: SubnetArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.subnet = mapped
    }

    /**
     * @param argument The reference to the subnet resource.
     */
    @JvmName("dsjkiytnvtudymdn")
    public suspend fun subnet(argument: suspend SubnetArgsBuilder.() -> Unit) {
        val toBeMapped = SubnetArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.subnet = mapped
    }

    /**
     * @param value A list of availability zones denoting the IP allocated for the resource needs to come from.
     */
    @JvmName("xhosfbisditjrfyt")
    public suspend fun zones(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.zones = mapped
    }

    /**
     * @param values A list of availability zones denoting the IP allocated for the resource needs to come from.
     */
    @JvmName("glirpjecmrxubgbo")
    public suspend fun zones(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.zones = mapped
    }

    internal fun build(): FrontendIPConfigurationArgs = FrontendIPConfigurationArgs(
        gatewayLoadBalancer = gatewayLoadBalancer,
        id = id,
        name = name,
        privateIPAddress = privateIPAddress,
        privateIPAddressVersion = privateIPAddressVersion,
        privateIPAllocationMethod = privateIPAllocationMethod,
        publicIPAddress = publicIPAddress,
        publicIPPrefix = publicIPPrefix,
        subnet = subnet,
        zones = zones,
    )
}
